@@ -7,7 +7,6 @@
     version 2 of the License, or (at your option) any later version.
  */
 
-#include <config-kstars.h>
 #include <QProcess>
 
 #include "kstars.h"
@@ -27,6 +26,9 @@
 #include "fitsviewer/fitstab.h"
 #include "fitsviewer/fitsview.h"
 
+#include "ekosmanager.h"
+#include "kstars.h"
+
 #ifdef HAVE_QJSON
 #include "onlineastrometryparser.h"
 #endif
@@ -74,10 +76,12 @@ Align::Align()
     connect(correctAltB, SIGNAL(clicked()), this, SLOT(correctAltError()));
     connect(correctAzB, SIGNAL(clicked()), this, SLOT(correctAzError()));
     connect(loadSlewB, SIGNAL(clicked()), this, SLOT(loadFITS()));
+    connect(kcfg_solverOTA, SIGNAL(toggled(bool)), this, SLOT(syncTelescopeInfo()));
 
     kcfg_solverXBin->setValue(Options::solverXBin());
     kcfg_solverYBin->setValue(Options::solverYBin());
     kcfg_solverUpdateCoords->setChecked(Options::solverUpdateCoords());
+    kcfg_solverPreview->setChecked(Options::solverPreview());
 
     syncBoxesB->setIcon(KIcon("edit-copy"));
     clearBoxesB->setIcon(KIcon("edit-clear"));
@@ -134,6 +138,9 @@ Align::Align()
         connect(parser, SIGNAL(solverFailed()), this, SLOT(solverFailed()));
     }
 
+    kcfg_solverOptions->setText(Options::solverOptions());
+    kcfg_solverOTA->setChecked(Options::solverOTA());
+
 }
 
 Align::~Align()
@@ -243,26 +250,23 @@ void Align::syncTelescopeInfo()
 
     if (nvp)
     {
-        INumber *np = IUFindNumber(nvp, "TELESCOPE_APERTURE");
+        INumber *np = NULL;
+
+        if (kcfg_solverOTA->isChecked())
+            np = IUFindNumber(nvp, "GUIDER_APERTURE");
+        else
+            np = IUFindNumber(nvp, "TELESCOPE_APERTURE");
 
         if (np && np->value > 0)
             aperture = np->value;
-        else
-        {
-            np = IUFindNumber(nvp, "GUIDER_APERTURE");
-            if (np && np->value > 0)
-                aperture = np->value;
-        }
 
-        np = IUFindNumber(nvp, "TELESCOPE_FOCAL_LENGTH");
+        if (kcfg_solverOTA->isChecked())
+            np = IUFindNumber(nvp, "GUIDER_FOCAL_LENGTH");
+        else
+            np = IUFindNumber(nvp, "TELESCOPE_FOCAL_LENGTH");
+
         if (np && np->value > 0)
             focal_length = np->value;
-        else
-        {
-            np = IUFindNumber(nvp, "GUIDER_FOCAL_LENGTH");
-            if (np && np->value > 0)
-                focal_length = np->value;
-        }
     }
 
     if (focal_length == -1 || aperture == -1)
@@ -316,6 +320,18 @@ void Align::syncCCDInfo()
     targetChip->getFrame(&x,&y,&ccd_width,&ccd_height);
     kcfg_solverXBin->setEnabled(targetChip->canBin());
     kcfg_solverYBin->setEnabled(targetChip->canBin());
+    if (targetChip->canBin())
+    {
+        int binx=1,biny=1;
+        targetChip->getMaxBin(&binx, &biny);
+        kcfg_solverXBin->setMaximum(binx);
+        kcfg_solverYBin->setMaximum(biny);
+    }
+    else
+    {
+        kcfg_solverXBin->setValue(1);
+        kcfg_solverYBin->setValue(1);
+    }
 
     if (ccd_hor_pixel == -1 || ccd_ver_pixel == -1)
         return;
@@ -338,9 +354,7 @@ void Align::calculateFOV()
     fov_x /= 60.0;
     fov_y /= 60.0;
 
-    FOVOut->setText(QString("%1' x %2'").arg(fov_x, 0, 'g', 3).arg(fov_y, 0, 'g', 3));
-
-    parser->verifyIndexFiles(fov_x, fov_y);
+    FOVOut->setText(QString("%1' x %2'").arg(fov_x, 0, 'g', 3).arg(fov_y, 0, 'g', 3));    
 
 }
 
@@ -373,8 +387,21 @@ void Align::generateArgs()
 
     getFormattedCoords(ra, dec, ra_dms, dec_dms);
 
-    solver_args << "--no-verify" << "--no-plots" << "--no-fits2fits" << "--resort"
-                << "--downsample" << "2" << "-O" << "-L" << fov_low << "-H" << fov_high << "-u" << "aw";
+    if (kcfg_solverOptions->text().isEmpty())
+    {
+        solver_args << "--no-verify" << "--no-plots" << "--no-fits2fits" << "--resort"
+                    << "--downsample" << "2" << "-O" << "-L" << fov_low << "-H" << fov_high << "-u" << "aw";
+    }
+    else
+    {
+        solver_args = kcfg_solverOptions->text().split(" ");
+        int fov_low_index = solver_args.indexOf("-L");
+        if (fov_low_index != -1)
+            solver_args.replace(fov_low_index+1, fov_low);
+        int fov_high_index = solver_args.indexOf("-H");
+        if (fov_high_index != -1)
+            solver_args.replace(fov_high_index+1, fov_high);
+    }
 
     if (raBox->isEmpty() == false && decBox->isEmpty() == false)
     {
@@ -407,10 +434,27 @@ void Align::generateArgs()
             return;
         }
 
-        solver_args << "-3" << QString().setNum(ra.Degrees()) << "-4" << QString().setNum(dec.Degrees()) << "-5" << QString().setNum(radius);
+        int ra_index = solver_args.indexOf("-3");
+        if (ra_index == -1)
+            solver_args << "-3" << QString().setNum(ra.Degrees());
+        else
+            solver_args.replace(ra_index+1, QString().setNum(ra.Degrees()));
+
+        int de_index = solver_args.indexOf("-4");
+        if (de_index == -1)
+            solver_args << "-4" << QString().setNum(dec.Degrees());
+        else
+            solver_args.replace(de_index+1, QString().setNum(dec.Degrees()));
+
+        int rad_index = solver_args.indexOf("-5");
+        if (rad_index == -1)
+            solver_args << "-5" << QString().setNum(radius);
+        else
+            solver_args.replace(rad_index+1, QString().setNum(radius));
+
      }
 
-    solverOptions->setText(solver_args.join(" "));
+    kcfg_solverOptions->setText(solver_args.join(" "));
 }
 
 void Align::checkLineEdits()
@@ -467,12 +511,16 @@ bool Align::capture()
     if (currentCCD->isConnected() == false)
     {
         appendLogText(i18n("Error: Lost connection to CCD."));
+        if (Options::playAlignmentAlarm())
+                KStars::Instance()->ekosManager()->playError();
         return false;
     }
 
    connect(currentCCD, SIGNAL(BLOBUpdated(IBLOB*)), this, SLOT(newFITS(IBLOB*)));
 
-   targetChip->setCaptureMode(FITS_WCSM);
+   targetChip->setCaptureMode( kcfg_solverPreview->isChecked() ? FITS_NORMAL : FITS_WCSM);
+   if (kcfg_solverPreview->isChecked())
+       targetChip->setCaptureFilter(FITS_AUTO_STRETCH);
    targetChip->setBinning(kcfg_solverXBin->value(), kcfg_solverYBin->value());
    targetChip->setFrameType(ccdFrame);
 
@@ -511,15 +559,20 @@ void Align::startSovling(const QString &filename, bool isGenerated)
     Options::setSolverYBin(kcfg_solverYBin->value());
     Options::setSolverUpdateCoords(kcfg_solverUpdateCoords->isChecked());
     Options::setSolverOnline(kcfg_onlineSolver->isChecked());
+    Options::setSolverPreview(kcfg_solverPreview->isChecked());
+    Options::setSolverOptions(kcfg_solverOptions->text());
+    Options::setSolverOTA(kcfg_solverOTA->isChecked());
 
     currentTelescope->getEqCoords(&ra, &dec);
 
     targetCoord.setRA(ra);
     targetCoord.setDec(dec);
 
+    parser->verifyIndexFiles(fov_x, fov_y);
+
     solverTimer.start();
 
-    solverArgs = solverOptions->text().split(" ");
+    solverArgs = kcfg_solverOptions->text().split(" ");
 
     parser->startSovler(filename, solverArgs, isGenerated);
 
@@ -544,12 +597,17 @@ void Align::solverFinished(double orientation, double ra, double dec)
      SolverRAOut->setText(ra_dms);
      SolverDecOut->setText(dec_dms);
 
+     if (Options::playAlignmentAlarm())
+             KStars::Instance()->ekosManager()->playOk();
+
      executeMode();
 
 }
 
 void Align::solverFailed()
 {
+    if (Options::playAlignmentAlarm())
+            KStars::Instance()->ekosManager()->playError();
     pi->stopAnimation();
     stopB->setEnabled(false);
     solveB->setEnabled(true);
@@ -611,6 +669,7 @@ void Align::updateScopeCoords(INumberVectorProperty *coord)
 
         telescopeCoord.setRA(coord->np[0].value);
         telescopeCoord.setDec(coord->np[1].value);
+        telescopeCoord.EquatorialToHorizontal(KStarsData::Instance()->lst(), KStarsData::Instance()->geo()->lat());
 
         ScopeRAOut->setText(ra_dms);
         ScopeDecOut->setText(dec_dms);
@@ -792,6 +851,7 @@ void Align::executePolarAlign()
 void Align::measureAzError()
 {
     static double initRA=0, initDEC=0, finalRA=0, finalDEC=0;
+    int hemisphere = KStarsData::Instance()->geo()->lat()->Degrees() > 0 ? 0 : 1;
 
     switch (azStage)
     {
@@ -799,7 +859,7 @@ void Align::measureAzError()
 
         // Display message box confirming user point scope near meridian and south
 
-        if (KMessageBox::warningContinueCancel( 0, hemisphereCombo->currentIndex() == 0
+        if (KMessageBox::warningContinueCancel( 0, hemisphere == 0
                                                    ? i18n("Point the telescope at the southern meridian. Press continue when ready.")
                                                    : i18n("Point the telescope at the northern meridian. Press continue when ready.")
                                                 , i18n("Polar Alignment Measurement"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
@@ -884,9 +944,7 @@ void Align::measureAltError()
 
         // Display message box confirming user point scope near meridian and south
 
-        if (KMessageBox::warningContinueCancel( 0, altDirCombo->currentIndex() == 0
-                                                   ? i18n("Point the telescope to the east with a minimum altitude of 20 degrees. Press continue when ready.")
-                                                   : i18n("Point the telescope to the west with a minimum altitude of 20 degrees. Press continue when ready.")
+        if (KMessageBox::warningContinueCancel( 0, i18n("Point the telescope to the eastern or western horizon with a minimum altitude of 20 degrees. Press continue when ready.")
                                                 , i18n("Polar Alignment Measurement"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
                                                 "ekos_measure_alt_error")!=KMessageBox::Continue)
             return;
@@ -966,6 +1024,11 @@ void Align::calculatePolarError(double initRA, double initDEC, double finalRA, d
     double raMotion = finalRA - initRA;
     decDeviation = finalDEC - initDEC;
 
+    // Northern/Southern hemisphere
+    int hemisphere = KStarsData::Instance()->geo()->lat()->Degrees() > 0 ? 0 : 1;
+    // East/West of meridian
+    int horizon    = (telescopeCoord.az().Degrees() > 0 && telescopeCoord.az().Degrees() <= 180) ? 0 : 1;
+
     // How much time passed siderrally form initRA to finalRA?
     double RATime = fabs(raMotion / SIDRATE) / 60.0;
 
@@ -975,38 +1038,39 @@ void Align::calculatePolarError(double initRA, double initDEC, double finalRA, d
     // Equation by Frank Berret (Measuring Polar Axis Alignment Error, page 4)
     // In degrees
     double deviation = (3.81 * (decDeviation * 3600) ) / ( RATime * cos(initDEC * dms::DegToRad)) / 60.0;
+    dms devDMS(fabs(deviation));
 
     KLocalizedString deviationDirection;
 
-    switch (hemisphereCombo->currentIndex())
+    switch (hemisphere)
     {
         // Northern hemisphere
         case 0:
         if (azStage == AZ_FINISHED)
         {
             if (decDeviation > 0)
-                deviationDirection = ki18n("%1° too far west");
+                deviationDirection = ki18n("%1 too far west");
             else
-                deviationDirection = ki18n("%1° too far east");
+                deviationDirection = ki18n("%1 too far east");
         }
         else if (altStage == ALT_FINISHED)
         {
-            switch (altDirCombo->currentIndex())
+            switch (horizon)
             {
                 // East
                 case 0:
                 if (decDeviation > 0)
-                    deviationDirection = ki18n("%1° too far high");
+                    deviationDirection = ki18n("%1 too far high");
                 else
-                    deviationDirection = ki18n("%1° too far low");
+                    deviationDirection = ki18n("%1 too far low");
                 break;
 
                 // West
                 case 1:
                 if (decDeviation > 0)
-                    deviationDirection = ki18n("%1° too far low");
+                    deviationDirection = ki18n("%1 too far low");
                 else
-                    deviationDirection = ki18n("%1° too far high");
+                    deviationDirection = ki18n("%1 too far high");
                 break;
 
                 default:
@@ -1020,28 +1084,28 @@ void Align::calculatePolarError(double initRA, double initDEC, double finalRA, d
         if (azStage == AZ_FINISHED)
         {
             if (decDeviation > 0)
-                deviationDirection = ki18n("%1° too far east");
+                deviationDirection = ki18n("%1 too far east");
             else
-                deviationDirection = ki18n("%1° too far west");
+                deviationDirection = ki18n("%1 too far west");
         }
         else if (altStage == ALT_FINISHED)
         {
-            switch (altDirCombo->currentIndex())
+            switch (horizon)
             {
                 // East
                 case 0:
                 if (decDeviation > 0)
-                    deviationDirection = ki18n("%1° too far low");
+                    deviationDirection = ki18n("%1 too far low");
                 else
-                    deviationDirection = ki18n("%1° too far high");
+                    deviationDirection = ki18n("%1 too far high");
                 break;
 
                 // West
                 case 1:
                 if (decDeviation > 0)
-                    deviationDirection = ki18n("%1° too far high");
+                    deviationDirection = ki18n("%1 too far high");
                 else
-                    deviationDirection = ki18n("%1° too far low");
+                    deviationDirection = ki18n("%1 too far low");
                 break;
 
                 default:
@@ -1057,13 +1121,15 @@ void Align::calculatePolarError(double initRA, double initDEC, double finalRA, d
 
     if (azStage == AZ_FINISHED)
     {
-        azError->setText(deviationDirection.subs(QString("%1").arg(fabs(deviation), 0, 'g', 3)).toString());
+        azError->setText(deviationDirection.subs(QString("%1").arg(devDMS.toDMSString())).toString());
+        //azError->setText(deviationDirection.subs(QString("%1")azDMS.toDMSString());
         azDeviation = deviation * (decDeviation > 0 ? 1 : -1);
         correctAzB->setEnabled(true);
     }
     if (altStage == ALT_FINISHED)
     {
-        altError->setText(deviationDirection.subs(QString("%1").arg(fabs(deviation), 0, 'g', 3)).toString());
+        //altError->setText(deviationDirection.subs(QString("%1").arg(fabs(deviation), 0, 'g', 3)).toString());
+        altError->setText(deviationDirection.subs(QString("%1").arg(devDMS.toDMSString())).toString());
         altDeviation = deviation * (decDeviation > 0 ? 1 : -1);
         correctAltB->setEnabled(true);
     }
