@@ -54,23 +54,47 @@ void ClientManager::newDevice(INDI::BaseDevice *dp)
 {
     setBLOBMode(B_ALSO, dp->getDeviceName());
 
+    DriverInfo *deviceDriver=NULL;
+
+    // First iteration find unique matches
     foreach(DriverInfo *dv, managedDrivers)
     {
-        QString dvName = dv->getName().split(" ").first();
-        if (dvName.isEmpty())
-            dvName = dv->getName();
-        if (dv->getUniqueLabel() == dp->getDeviceName() ||
-                QString(dp->getDeviceName()).startsWith(dvName, Qt::CaseInsensitive) || dv->getDriverSource() == HOST_SOURCE)
+        if (dv->getUniqueLabel() == QString(dp->getDeviceName()))
         {
-            dv->setUniqueLabel(dp->getDeviceName());
+            deviceDriver = dv;
+            break;
+        }
 
-            DeviceInfo *devInfo = new DeviceInfo(dv, dp);
-            dv->addDevice(devInfo);
-            emit newINDIDevice(devInfo);
-            return;
+    }
+
+    // Second iteration find partial matches
+    if (deviceDriver == NULL)
+    {
+        foreach(DriverInfo *dv, managedDrivers)
+        {
+            QString dvName = dv->getName();
+            dvName = dv->getName().split(" ").first();
+            if (dvName.isEmpty())
+                dvName = dv->getName();
+            if (dv->getUniqueLabel() == dp->getDeviceName() ||
+                    QString(dp->getDeviceName()).startsWith(dvName, Qt::CaseInsensitive) ||
+                    dv->getDriverSource() == HOST_SOURCE || dv->getDriverSource() == GENERATED_SOURCE)
+            {
+                deviceDriver = dv;
+                break;
+            }
         }
     }
 
+    if (deviceDriver == NULL)
+        return;
+
+    deviceDriver->setUniqueLabel(dp->getDeviceName());
+    DeviceInfo *devInfo = new DeviceInfo(deviceDriver, dp);
+    deviceDriver->addDevice(devInfo);
+    emit newINDIDevice(devInfo);
+    return;
+
 }
 
 void ClientManager::newProperty(INDI::Property *prop)
@@ -131,22 +155,26 @@ void ClientManager::appendManagedDriver(DriverInfo *dv)
 }
 
 void ClientManager::removeManagedDriver(DriverInfo *dv)
-{
-    managedDrivers.removeOne(dv);
-
+{    
     dv->setClientState(false);
 
     foreach(DeviceInfo *di, dv->getDevices())
+    {
         emit INDIDeviceRemoved(di);
+        dv->removeDevice(di);
+    }
 
     foreach(DriverInfo *dv, managedDrivers)
     {
-        if (dv->getDriverSource() == HOST_SOURCE)
+        if (dv->getDriverSource() == GENERATED_SOURCE)
         {
             managedDrivers.removeOne(dv);
             delete (dv);
+            return;
         }
     }
+
+    managedDrivers.removeOne(dv);
 }
 
 
