@@ -80,6 +80,8 @@ bool ServerManager::start()
 
     indiFIFO.setFileName(fifoFile);
 
+    driverCrashed = false;
+
    if (!indiFIFO.open(QIODevice::ReadWrite | QIODevice::Text))
    {
          qDebug() << "Unable to create INDI FIFO file: " << fifoFile << endl;
@@ -118,7 +120,8 @@ bool ServerManager::startDriver(DriverInfo *dv)
     managedDrivers.append(dv);
     dv->setServerManager(this);
 
-    dv->setUniqueLabel(DriverManager::Instance()->getUniqueDeviceLabel(dv->getTreeLabel()));
+    if (dv->getUniqueLabel().isEmpty())
+        dv->setUniqueLabel(DriverManager::Instance()->getUniqueDeviceLabel(dv->getTreeLabel()));
 
      if (KStandardDirs::findExe(dv->getDriver()).isEmpty())
      {
@@ -126,7 +129,8 @@ bool ServerManager::startDriver(DriverInfo *dv)
          return false;
      }
 
-        //qDebug() << "Will run driver: " << dv->getName() << " with driver " << dv->getDriver() << endl;
+        //qDebug() << "Will run driver: " << dv->getName() << " with driver " << dv->getDriver() <<
+        //            " Unique Label " << dv->getUniqueLabel() << endl;
 
         if (dv->getSkeletonFile().isEmpty())
             out << "start " << dv->getDriver() << " -n \"" << dv->getUniqueLabel() << "\"" << endl;
@@ -214,10 +218,22 @@ void ServerManager::processServerError(QProcess::ProcessError err)
 
 void ServerManager::processStandardError()
 {
-
     serverBuffer.append(serverProcess->readAllStandardError());
 
-    //qDebug() << "Recevined new stderr from server " << serverBuffer << endl;
+    if (driverCrashed == false && (serverBuffer.contains("stdin EOF") || serverBuffer.contains("stderr EOF")))
+    {
+        QStringList parts = serverBuffer.split("Driver");
+        foreach(QString driver, parts)
+        {
+            if (driver.contains("stdin EOF") || driver.contains("stderr EOF"))
+            {
+                driverCrashed=true;
+                QString driverName = driver.left(driver.indexOf(':')).trimmed();
+                KMessageBox::information(0, i18n("KStars detected INDI driver %1 crashed. Please check INDI server log in the Device Manager.", driverName));
+                break;
+            }
+        }
+   }
 
     emit newServerLog();
 }
